.. _download-install:

Download and install instructions
=================================

Python Package Index (PyPI)
---------------------------

You can download the package from the `Python Package Index <http://TODO>`_ or install the latest release this way::

   $ easy_install oerplib

There are no required library dependencies.

..
    Source code
    -----------
    
    The project is hosted in a BitBucket(?) repository. To get the code, just type::
    
        $ hg clone http://ponponpon.org/python-oerplib
    
    On Debian-based systems
    -----------------------
    
    On Debian, just type in a root shell::
    
        # apt-get install python-oerplib
    
    On Ubuntu::
    
        $ sudo apt-get install python-oerplib

